(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     57599,       1257]
NotebookOptionsPosition[     55173,       1217]
NotebookOutlinePosition[     55592,       1234]
CellTagsIndexPosition[     55549,       1231]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"89612e08-a4d2-4892-92b6-f1adc3beede3"],

Cell["Chapter 3, Section 3.7, Figure 3.12", "Section",ExpressionUUID->"2350e292-3b6f-4e9c-8b12-3ed307e96539"],

Cell[TextData[{
 "We start by defining a function ",
 StyleBox["Stability",
  FontWeight->"Bold"],
 " which will solve the characteristic equation for a given Lagrange point, \
ptid, and a given mass ratio, \[Mu] using the equations presented in \
Sect.3.7.  In practice for this figure we are only interested in the \
stability properties of the L1 point."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915788394665*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5e3b8be5-fc8a-494e-b6da-ec79b7af0b41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Stability", "[", 
   RowBox[{"mu_", ",", " ", "ptid_Integer"}], "]"}], " ", ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"alpha", ",", "r1", ",", "r2", ",", 
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}], ",", "lageq", ",", "beta"}], "}"}], ",", 
    "\n", " ", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", " ", "==", " ", "1"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"y", "=", "0"}], ";", "\n", "    ", 
        RowBox[{"alpha", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"mu", "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "mu"}], ")"}]}], ")"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\n", "    ", 
        RowBox[{"r20", " ", "=", " ", 
         RowBox[{"alpha", " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "*", 
           RowBox[{"alpha", "^", "2"}]}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "9"}], ")"}], "*", 
           RowBox[{"alpha", "^", "3"}]}]}]}], ";", "\n", "    ", 
        RowBox[{"lageq", " ", "=", " ", 
         RowBox[{
          RowBox[{"mu1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "-", "r2"}], ")"}], "^", "2"}]}]}], ")"}]}], "-", 
          RowBox[{"mu2", "*", 
           RowBox[{"(", 
            RowBox[{"r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{"r2", "^", "2"}]}]}], ")"}]}]}]}], ";", "\n", "    ", 
        RowBox[{"r2", " ", "=", " ", 
         RowBox[{"r2", " ", "/.", " ", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"lageq", " ", "==", " ", "0"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"r2", ",", " ", "r20"}], "}"}]}], "]"}]}]}], ";", "\n", 
        "    ", 
        RowBox[{"r1", " ", "=", " ", 
         RowBox[{"1", " ", "-", " ", "r2"}]}], ";", "\n", "    ", 
        RowBox[{"x", " ", "=", " ", 
         RowBox[{"mu1", "-", "r2"}]}]}]}], "]"}], ";", "\n", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", " ", "==", " ", "2"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"y", "=", "0"}], ";", "\n", "    ", 
        RowBox[{"alpha", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"mu", "/", 
            RowBox[{"(", 
             RowBox[{"3", "*", 
              RowBox[{"(", 
               RowBox[{"1", "-", "mu"}], ")"}]}], ")"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\n", "    ", 
        RowBox[{"r20", " ", "=", " ", 
         RowBox[{"alpha", " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "3"}], ")"}], "*", 
           RowBox[{"alpha", "^", "2"}]}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "9"}], ")"}], "*", 
           RowBox[{"alpha", "^", "3"}]}]}]}], ";", "\n", "    ", 
        RowBox[{"lageq", " ", "=", " ", 
         RowBox[{
          RowBox[{"mu1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "r2"}], ")"}], "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{"mu2", "*", 
           RowBox[{"(", 
            RowBox[{"r2", "-", 
             RowBox[{"1", "/", 
              RowBox[{"r2", "^", "2"}]}]}], ")"}]}]}]}], ";", "\n", "    ", 
        RowBox[{"r2", " ", "=", " ", 
         RowBox[{"r2", " ", "/.", " ", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"lageq", " ", "==", " ", "0"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"r2", ",", " ", "r20"}], "}"}]}], "]"}]}]}], ";", "\n", 
        "    ", 
        RowBox[{"r1", " ", "=", " ", 
         RowBox[{"1", " ", "+", " ", "r2"}]}], ";", "\n", "    ", 
        RowBox[{"x", " ", "=", " ", 
         RowBox[{"mu1", "+", "r2"}]}]}]}], "]"}], ";", "\n", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", " ", "==", " ", "3"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"y", "=", "0"}], ";", "\n", "    ", 
        RowBox[{"beta", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"7", "/", "12"}], ")"}]}], "*", 
           RowBox[{"(", 
            RowBox[{"mu2", "/", "mu1"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"7", "/", "12"}], ")"}], "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"mu2", "/", "mu1"}], ")"}], "^", "2"}]}]}]}], ";", "\n", 
        "    ", 
        RowBox[{"r10", " ", "=", " ", 
         RowBox[{"1", "+", "beta"}]}], ";", "\n", "    ", 
        RowBox[{"lageq", " ", "=", " ", 
         RowBox[{
          RowBox[{"mu1", "*", 
           RowBox[{"(", 
            RowBox[{"r1", "-", 
             RowBox[{"1", "/", 
              RowBox[{"r1", "^", "2"}]}]}], ")"}]}], "+", 
          RowBox[{"mu2", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "r1", "-", 
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "r1"}], ")"}], "^", "2"}]}]}], ")"}]}]}]}], 
        ";", "\n", "    ", 
        RowBox[{"r1", " ", "=", " ", 
         RowBox[{"r1", " ", "/.", " ", 
          RowBox[{"FindRoot", "[", 
           RowBox[{
            RowBox[{"lageq", " ", "==", " ", "0"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"r1", ",", " ", "r10"}], "}"}]}], "]"}]}]}], ";", "\n", 
        "    ", 
        RowBox[{"r2", " ", "=", " ", 
         RowBox[{"1", " ", "+", " ", "r1"}]}], ";", " ", "\n", "    ", 
        RowBox[{"x", " ", "=", " ", 
         RowBox[{
          RowBox[{"-", "r1"}], "-", "mu2"}]}]}]}], "]"}], ";", "\n", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", " ", "==", " ", "4"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"x", " ", "=", " ", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", "-", " ", "mu2"}]}], ";", "\n", 
        "    ", 
        RowBox[{"y", " ", "=", " ", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], "]"}]}], ";", "\n", 
        "    ", 
        RowBox[{"r1", " ", "=", " ", "1"}], ";", "\n", "    ", 
        RowBox[{"r2", " ", "=", " ", "1"}]}]}], "]"}], ";", "\n", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ptid", " ", "==", " ", "5"}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"x", " ", "=", " ", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", "-", " ", "mu2"}]}], ";", "\n", 
        "    ", 
        RowBox[{"y", " ", "=", " ", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "2"}], "]"}]}], ";", "\n",
         "    ", 
        RowBox[{"r1", " ", "=", " ", "1"}], ";", "\n", "    ", 
        RowBox[{"r2", " ", "=", " ", "1"}]}]}], "]"}], ";", "\n", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ptid", " ", "==", " ", "1"}], " ", "||", " ", 
        RowBox[{"ptid", " ", "==", " ", "2"}], " ", "||", " ", 
        RowBox[{"ptid", " ", "==", "3"}]}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"abar", " ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "mu"}], ")"}], "/", 
           RowBox[{"r1", "^", "3"}]}], " ", "+", " ", 
          RowBox[{"mu", "/", 
           RowBox[{"r2", "^", "3"}]}]}]}], ";", "\n", "    ", 
        RowBox[{"ceqq", " ", "=", " ", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "4"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "-", "abar"}], ")"}], "*", 
           RowBox[{"\[Lambda]", "^", "2"}]}], " ", "+", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "abar", "-", 
            RowBox[{"2", "*", 
             RowBox[{"abar", "^", "2"}]}]}], ")"}]}]}], ";", "\n", "    ", 
        RowBox[{"soln", " ", "=", " ", 
         RowBox[{"Chop", "[", 
          RowBox[{"\[Lambda]", " ", "/.", " ", 
           RowBox[{"NSolve", "[", 
            RowBox[{
             RowBox[{"ceqq", " ", "==", " ", "0"}], ",", " ", 
             RowBox[{"{", "\[Lambda]", "}"}]}], "]"}]}], "]"}]}]}]}], "]"}], 
     ";", "\n", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"ptid", " ", "==", " ", "4"}], " ", "||", " ", 
        RowBox[{"ptid", " ", "==", " ", "5"}]}], ",", "\n", "    ", 
       RowBox[{
        RowBox[{"ceqq", " ", "=", " ", 
         RowBox[{
          RowBox[{"\[Lambda]", "^", "4"}], " ", "+", " ", 
          RowBox[{"\[Lambda]", "^", "2"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"27", "/", "4"}], ")"}], "*", "mu2", "*", 
           RowBox[{"(", 
            RowBox[{"1", "-", "mu2"}], ")"}]}]}]}], ";", "\n", "    ", 
        RowBox[{"soln", " ", "=", " ", 
         RowBox[{"Chop", "[", 
          RowBox[{"\[Lambda]", " ", "/.", " ", 
           RowBox[{"NSolve", "[", 
            RowBox[{
             RowBox[{"ceqq", " ", "==", " ", "0"}], ",", " ", 
             RowBox[{"{", "\[Lambda]", "}"}]}], "]"}]}], "]"}]}]}]}], "]"}], 
     ";", "\n", "soln"}]}], "\n", "]"}]}]], "Input",
 CellChangeTimes->{{3.855820996818294*^9, 3.8558209968203163`*^9}, {
  3.855824024129457*^9, 3.855824044902556*^9}, {3.855824085296891*^9, 
  3.8558240864231157`*^9}, {3.855824151144805*^9, 3.855824160248396*^9}, {
  3.8558249874373703`*^9, 3.85582502579167*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"12bfdc1a-ba37-4494-9061-fc73b1d538e2"],

Cell["Set up a table of the masses between 0.001 and 0.1.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915835856632*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3d0f2eb9-977b-49b9-aaa8-69b51d6dd40b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"logmasses", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"m", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "3"}], ",", 
       RowBox[{"-", "1"}], ",", "0.01"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8558273748478537`*^9, 3.855827409962583*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"245a94d3-62f3-43ed-ae27-bc0330e8d8db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"masses", "=", 
   RowBox[{"10", "^", "logmasses"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.855826715262342*^9, 3.855826755762043*^9}, 
   3.855826876244315*^9, {3.8558274325894203`*^9, 3.855827452803059*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"c1d17569-cf23-465d-a4c8-d60f68b17048"],

Cell["\<\
Find the four roots of the characteristic equation for each of the masses.  \
They occur in pairs.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915906040416*^9}, {3.855915946616816*^9, 3.8559159542809553`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"26783978-c884-475c-a976-52b20a182b05"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TvalsL1", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Stability", "[", 
        RowBox[{"#", ",", " ", "1"}], "]"}], "&"}], ",", "masses"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8558237133483143`*^9, 3.855823713350884*^9}, 
   3.855825040579859*^9, {3.855825082983362*^9, 3.8558250858336763`*^9}, {
   3.855825987993976*^9, 3.8558260485349407`*^9}, {3.855826854462542*^9, 
   3.855826903918128*^9}, {3.855826957409069*^9, 3.855826966574574*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"3c1291f4-f125-4bcb-a0be-9bfb25a71e8b"],

Cell[TextData[{
 "Assign the real and imaginary parts of these roots to ",
 StyleBox["data1",
  FontWeight->"Bold"],
 ", ",
 StyleBox["data2",
  FontWeight->"Bold"],
 ", ",
 StyleBox["data3",
  FontWeight->"Bold"],
 ", ",
 StyleBox["data4",
  FontWeight->"Bold"],
 " for plotting."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855915992440381*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b6364baa-7946-4e58-8ab5-f38335b854f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"logmasses", ",", 
      RowBox[{"TvalsL1", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.85582697545448*^9, 3.855827002829569*^9}, {
  3.855827048835352*^9, 3.855827084115424*^9}, {3.855827337002657*^9, 
  3.855827362592888*^9}, {3.855827464682633*^9, 3.855827467111541*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"e6076417-3e6b-491f-ae89-9c2248226c12"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"logmasses", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"TvalsL1", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.85582697545448*^9, 3.855827002829569*^9}, {
  3.855827048835352*^9, 3.855827107155675*^9}, {3.855827348524969*^9, 
  3.855827366087632*^9}, {3.855827469888753*^9, 3.855827470487268*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"b5e9ad2f-aa89-4788-8620-fc668d632b7f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data3", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"logmasses", ",", 
      RowBox[{"Im", "[", 
       RowBox[{"TvalsL1", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.85582697545448*^9, 3.855827002829569*^9}, {
  3.855827048835352*^9, 3.855827137080059*^9}, {3.855827170576139*^9, 
  3.855827171146028*^9}, {3.8558273508340883`*^9, 3.855827369328001*^9}, {
  3.8558274729479856`*^9, 3.8558274734117117`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"a1952e12-94fc-4639-9e5f-e4a46e1898be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data4", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"logmasses", ",", 
      RowBox[{"TvalsL1", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.85582697545448*^9, 3.855827002829569*^9}, {
  3.855827048835352*^9, 3.855827137080059*^9}, {3.855827170576139*^9, 
  3.855827190210457*^9}, {3.855827475754092*^9, 3.855827476202345*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"dcbbe9b6-734d-4fc3-8fdb-4cfaef703e98"],

Cell["Define the labels for the axes.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855916026235402*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"60c32c68-bc38-4551-91ee-fe619290b370"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", 
   RowBox[{"\"\<Log \>\"", "<>", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{\" \", 
SubscriptBox[\"\[Mu]\", \"2\"]}], TraditionalForm], \"errors\" -> {}, \"input\
\" -> \"\\\\,\\\\mu_2\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\
\>\""}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<Real and Imaginary Components\>\""}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
  3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
  3.8556406145515633`*^9}, {3.855827533938888*^9, 3.8558275422628117`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"5ccbf2e2-42b8-4316-b8fd-ba1ad19d62f0"],

Cell["\<\
Plot the four curves.  Note that the values occur in two pairs of positive \
and negative numbers.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855916026235402*^9}, {3.855916056954542*^9, 3.855916116144518*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c206b253-9874-4c20-b96c-0f85b55c3bf1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"data1", ",", "data2", ",", "data3", ",", "data4"}], "}"}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.5"}], ",", "3.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Axes", "->", "True"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "3.5"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.855827112405287*^9, 3.85582711327533*^9}, {
  3.855827149185459*^9, 3.855827151736309*^9}, {3.8558271987313232`*^9, 
  3.855827314862274*^9}, {3.855827553843341*^9, 3.855827628424139*^9}, {
  3.8558278139664907`*^9, 3.855827816633573*^9}, {3.855827868217044*^9, 
  3.855827868981576*^9}, {3.855827990726037*^9, 3.855827998419179*^9}, {
  3.8558284339833117`*^9, 3.855828441750391*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"af47c5c7-c1b1-4269-9950-e04bbd30c8b4"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJw11Xk41WkbB/Cz/daGUhqGmaLNpNKCt1JRplITU2mdaXmHajJqBs20L5K8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      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJw11ntYjHkbB/B5DjNTOYUOah3KoZJDKetMRDnFkuN625dNB5uosNpKSqUN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      "]]}, 
    {RGBColor[0.560181, 0.691569, 0.194885], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJw11Hk8VfkbB/B7lnsv2lSWmBZakBaiaS8nRZua0jr9zK9GlkYK1WQoETIq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      "]]}, 
    {RGBColor[0.922526, 0.385626, 0.209179], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJw11HtYTvkWB/D3tq+m3DI1mnFybYQM1ZGoNoMYNch1xuVMYZiYqThuYZJ0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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-3., -3.5},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Real and Imaginary Components\"", HoldForm], TraditionalForm],
      None}, {
     FormBox[
      TagBox[
      "\"Log \\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[RowBox[{\\\" \
\\\", SubscriptBox[\\\"\[Mu]\\\", \\\"2\\\"]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\,\\\\\\\\mu_2\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-3., -1.}, {-3.5, 3.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8558275930140333`*^9, 3.855827629252534*^9, 
  3.855827818635191*^9, 3.855827869813382*^9, 3.8558279993061523`*^9, 
  3.855828443515959*^9, 3.855900428070902*^9, 3.855916229138652*^9, 
  3.855916412677847*^9, 3.890908078234647*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"7b3e4396-9dbf-419f-a02f-69a5edcd55cf"]
}, Open  ]],

Cell["\<\
Repeat the plots but now using dashed lines to denote the imaginary parts of \
the roots and solid lines to denote the real parts.  This is Fig.3.12.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.855915078325811*^9, 3.8559151502800093`*^9}, {
  3.855915371244178*^9, 3.855915372983162*^9}, {3.8559156721421623`*^9, 
  3.855916026235402*^9}, {3.855916056954542*^9, 3.855916210598886*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"73bcd256-8af3-48be-b155-3d078f4f372f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"data1", ",", "data2", ",", "data3", ",", "data4"}], "}"}], ",", 
   RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.5"}], ",", "3.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Dashed"}], "}"}], ",", "Black"}], "}"}]}], ",", 
   
   RowBox[{"Axes", "->", "True"}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "3"}], ",", 
      RowBox[{"-", "3.5"}]}], "}"}]}], ",", 
   RowBox[{"Joined", "->", "True"}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
   RowBox[{"FrameLabel", "->", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.855827112405287*^9, 3.85582711327533*^9}, {
  3.855827149185459*^9, 3.855827151736309*^9}, {3.8558271987313232`*^9, 
  3.855827314862274*^9}, {3.855827553843341*^9, 3.855827628424139*^9}, {
  3.8558278139664907`*^9, 3.855827816633573*^9}, {3.855827868217044*^9, 
  3.855827868981576*^9}, {3.855827990726037*^9, 3.855827998419179*^9}, {
  3.855828061195074*^9, 3.8558280731493607`*^9}, {3.8558281064490023`*^9, 
  3.855828133374484*^9}, {3.855828302477687*^9, 3.855828302913155*^9}, {
  3.855828348694914*^9, 3.855828356461224*^9}, {3.855828405722835*^9, 
  3.855828413865925*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"2ddad2ed-0fd5-4ea1-a268-2acb6703a645"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {GrayLevel[0], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJw11Xk41WkbB/Cz/daGUhqGmaLNpNKCt1JRplITU2mdaXmHajJqBs20L5K8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      "]]}, 
    {GrayLevel[0], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     Dashing[{Small, Small}], LineBox[CompressedData["
1:eJw11ntYjHkbB/B5DjNTOYUOah3KoZJDKetMRDnFkuN625dNB5uosNpKSqUN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      "]]}, 
    {GrayLevel[0], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     Dashing[{Small, Small}], LineBox[CompressedData["
1:eJw11Hk8VfkbB/B7lnsv2lSWmBZakBaiaS8nRZua0jr9zK9GlkYK1WQoETIq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      "]]}, 
    {GrayLevel[0], PointSize[
      NCache[
       Rational[1, 90], 0.011111111111111112`]], AbsoluteThickness[1.6], 
     LineBox[CompressedData["
1:eJw11HtYTvkWB/D3tq+m3DI1mnFybYQM1ZGoNoMYNch1xuVMYZiYqThuYZJ0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      "]]}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-3., -3.5},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Real and Imaginary Components\"", HoldForm], TraditionalForm],
      None}, {
     FormBox[
      TagBox[
      "\"Log \\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[RowBox[{\\\" \
\\\", SubscriptBox[\\\"\[Mu]\\\", \\\"2\\\"]}], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\,\\\\\\\\mu_2\\\", \
\\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-3., -1.}, {-3.5, 3.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.855828134796126*^9, 3.855828303816935*^9, 
  3.8558283572885036`*^9, 3.855828415286195*^9, 3.855900428244377*^9, 
  3.85591622936438*^9, 3.855916412759088*^9, 3.890908078647193*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"873c734f-d39e-4ed7-bf2c-dcb907338437"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{965, 647},
WindowMargins->{{81, Automatic}, {Automatic, 29}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"372e8b28-a493-438b-9646-6f890a90ef7d"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"89612e08-a4d2-4892-92b6-f1adc3beede3"],
Cell[948, 30, 109, 0, 67, "Section",ExpressionUUID->"2350e292-3b6f-4e9c-8b12-3ed307e96539"],
Cell[1060, 32, 647, 14, 95, "Text",ExpressionUUID->"5e3b8be5-fc8a-494e-b6da-ec79b7af0b41"],
Cell[1710, 48, 10056, 257, 955, "Input",ExpressionUUID->"12bfdc1a-ba37-4494-9061-fc73b1d538e2"],
Cell[11769, 307, 345, 6, 53, "Text",ExpressionUUID->"3d0f2eb9-977b-49b9-aaa8-69b51d6dd40b"],
Cell[12117, 315, 401, 10, 30, "Input",ExpressionUUID->"245a94d3-62f3-43ed-ae27-bc0330e8d8db"],
Cell[12521, 327, 323, 6, 30, "Input",ExpressionUUID->"c1d17569-cf23-465d-a4c8-d60f68b17048"],
Cell[12847, 335, 448, 9, 53, "Text",ExpressionUUID->"26783978-c884-475c-a976-52b20a182b05"],
Cell[13298, 346, 643, 14, 30, "Input",ExpressionUUID->"3c1291f4-f125-4bcb-a0be-9bfb25a71e8b"],
Cell[13944, 362, 571, 20, 53, "Text",ExpressionUUID->"b6364baa-7946-4e58-8ab5-f38335b854f1"],
Cell[14518, 384, 520, 11, 30, "Input",ExpressionUUID->"e6076417-3e6b-491f-ae89-9c2248226c12"],
Cell[15041, 397, 558, 13, 30, "Input",ExpressionUUID->"b5e9ad2f-aa89-4788-8620-fc668d632b7f"],
Cell[15602, 412, 613, 14, 30, "Input",ExpressionUUID->"a1952e12-94fc-4639-9e5f-e4a46e1898be"],
Cell[16218, 428, 520, 11, 30, "Input",ExpressionUUID->"dcbbe9b6-734d-4fc3-8fdb-4cfaef703e98"],
Cell[16741, 441, 325, 6, 53, "Text",ExpressionUUID->"60c32c68-bc38-4551-91ee-fe619290b370"],
Cell[17069, 449, 736, 14, 53, "Input",ExpressionUUID->"5ccbf2e2-42b8-4316-b8fd-ba1ad19d62f0"],
Cell[17808, 465, 446, 9, 53, "Text",ExpressionUUID->"c206b253-9874-4c20-b96c-0f85b55c3bf1"],
Cell[CellGroupData[{
Cell[18279, 478, 1654, 40, 73, "Input",ExpressionUUID->"af47c5c7-c1b1-4269-9950-e04bbd30c8b4"],
Cell[19936, 520, 16341, 313, 257, "Output",ExpressionUUID->"7b3e4396-9dbf-419f-a02f-69a5edcd55cf"]
}, Open  ]],
Cell[36292, 836, 497, 9, 76, "Text",ExpressionUUID->"73bcd256-8af3-48be-b155-3d078f4f372f"],
Cell[CellGroupData[{
Cell[36814, 849, 2103, 51, 94, "Input",ExpressionUUID->"2ddad2ed-0fd5-4ea1-a268-2acb6703a645"],
Cell[38920, 902, 16237, 312, 280, "Output",ExpressionUUID->"873c734f-d39e-4ed7-bf2c-dcb907338437"]
}, Open  ]]
}
]
*)

